@@ -18,6 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+
 /*
 ** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
 **
@@ -512,7 +513,7 @@ void document_holder::apply_settings_single (CDocument *d)
   d->textEdit->tab_sp_width = settings->value ("tab_sp_width", 8).toInt();
   d->textEdit->spaces_instead_of_tabs = settings->value ("spaces_instead_of_tabs", true).toBool();
 
-  d->textEdit->setTabStopWidth (d->textEdit->spaces_instead_of_tabs * d->textEdit->brace_width);
+  d->textEdit->setTabStopWidth (d->textEdit->tab_sp_width * d->textEdit->brace_width);
   
   d->textEdit->setup_brace_width();
 
