@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2009 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2010 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,25 +31,26 @@
 Diego Iastrubni <elcuco@kde.org> //some GPL'ed code from new-editor-diego-3, found on qtcentre forum
 */
 
+/*
+code from qwriter:
+ *   Copyright (C) 2009 by Gancov Kostya                                   *
+ *   kossne@mail.ru                                                        *
+*/
+
 
 #ifndef DOCUMENT_H
 #define DOCUMENT_H
 
 #include <QtGui>
+
 #include "logmemo.h"
 #include "tio.h"
 
-
-enum _TextType
-              {
-               Text_OFF = 0,
-               Text_SINGLELINECOMMENT,
-               Text_MULTILINECOMMENT,
-               Text_STRING,
-               Text_CHAR
-              };
+#include "todo.h"
 
 
+
+class LineNumberArea;
 class document_holder;
 class CDocument;
 
@@ -62,6 +63,8 @@ class CTEAEdit: public QPlainTextEdit
 private:
     
   QString indent_val;  
+  QList <QTextEdit::ExtraSelection> extraSelections;
+  QTextEdit::ExtraSelection selection;
 
 public:
 
@@ -69,10 +72,16 @@ public:
 
   QColor currentLineColor;
   QColor brackets_color;
+  QColor margin_color;
+  QColor linenums_bg;
+  QColor text_color;
+
+  QWidget *lineNumberArea;
 
   bool highlightCurrentLine;
   bool hl_brackets;
   bool draw_margin;
+  bool draw_linenums;
   
   bool use_hl_wrap;
 
@@ -82,47 +91,43 @@ public:
   int brace_width; //in pixels
   int margin_pos; //in chars
   int margin_x; //in pixels
-    
-  _TextType TextType;
+
 
   CTEAEdit (QWidget *parent = 0);
   ~CTEAEdit();
 
   void setCurrentLineColor (const QColor &newColor);
   void set_brackets_color (const QColor &newColor);
-
+  void set_show_linenums (bool enable);
   void set_show_margin (bool enable);
   void set_margin_pos (int mp);
-
   void set_hl_cur_line (bool enable);
   void set_hl_brackets (bool enable);
 
-  void dragEnterEvent (QDragEnterEvent *event);
-  void dropEvent (QDropEvent *event);
-
-  void paintBracketForward (QTextCursor & cur, int pos, const QChar &begin);
-  void paintBracketBack (QTextCursor & cur, int pos, const QChar &begin);
-  bool exists (int pos);
-  int ending (int pos, const QChar &ch);
-  int forwarding (int pos, const QChar &ch);
-
   void indent();
   void un_indent();
-  
   void calc_auto_indent();
   void setup_brace_width();
 
-
-private slots:
-
-  void cb_cursorPositionChanged();
+  void braceHighlight();
+  
+  void lineNumberAreaPaintEvent(QPaintEvent *event);
+  int lineNumberAreaWidth();
 
 protected:
 
+  void dragEnterEvent (QDragEnterEvent *event);
+  void dropEvent (QDropEvent *event);
   void paintEvent(QPaintEvent *event);
   void keyPressEvent (QKeyEvent *event);    
-};
+  void resizeEvent(QResizeEvent *event);
 
+private slots:
+
+  void updateLineNumberAreaWidth (int newBlockCount);
+  void cb_cursorPositionChanged();
+  void updateLineNumberArea (const QRect &, int);
+};
 
 
 class CSyntaxHighlighter: public QSyntaxHighlighter
@@ -146,6 +151,12 @@ public:
   bool casecare;
   bool wrap;
   
+  QString exts;
+  QString langs;
+    
+  QString cm_mult;
+  QString cm_single;
+    
   CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0);
 
   QVector<HighlightingRule> highlightingRules;
@@ -171,7 +182,13 @@ public:
   Q_PROPERTY(bool has_selection READ get_has_selection)
 
   bool cursor_xy_visible;
+  bool eol_changed;
 
+  QHash <QString, QString> fnameswoexts;
+  
+  QString new_eol;
+  QString def_eol;
+  
   document_holder *holder;
   CSyntaxHighlighter *highlighter;
   CTEAEdit *textEdit;
@@ -190,25 +207,23 @@ public:
   QString get_selected_text() const;
   void set_all_text (const QString &value);
   QString get_all_text() const;
-
   bool get_has_selection() const;
-
-  void create_new (void);
+  
+  void create_new();
   void set_tab_caption (const QString &fileName);
   bool save_with_name (const QString &fileName, const QString &codec);
   bool save_with_name_plain (const QString &fileName);
   void goto_pos (int pos);
   QString get_filename_at_cursor();
   QStringList get_words();
-  void set_hl(bool mode_auto = true, const QString &theext = "txt");
+  void set_hl (bool mode_auto = true, const QString &theext = "txt");
   bool open_file (const QString &fileName, const QString &codec);
   void insert_image (const QString &full_path);
-
-  void set_markup_mode ();
+  void set_markup_mode();
   void reload (const QString &enc);
-  int get_tab_idx (void);
+  int get_tab_idx();
   QString get_triplex();
-  void update_status ();
+  void update_status();
   void update_title (bool fullname = TRUE);
 };
 
@@ -217,23 +232,28 @@ class document_holder: public QObject
 {
   Q_OBJECT
 
-  public:
+public:
 
   CTioHandler tio_handler;
 
   QString fname_current_session;
 
-  QHash<QString, QString> palette;
-  QHash<QString, QString> hls;
+  QHash <QString, QString> palette;
+  QHash <QString, QString> hls;
 
   QLabel *l_status_bar;
   QString dir_config;
+  //QString dir_days;
+
   QString fname_crapbook;
 
+  CTodo todo;
+
+
   QString markup_mode;
   QStatusBar *status_bar;
   CLogMemo *log;
-  QList<CDocument*> list;
+  QList <CDocument*> list;
   QMainWindow *parent_wnd;
   QTabWidget *tab_widget;
   QSettings *settings;
@@ -244,18 +264,18 @@ class document_holder: public QObject
 
   ~document_holder();
 
-  CDocument* create_new (void);
+  CDocument* create_new();
   CDocument* open_file (const QString &fileName, const QString &codec);
   CDocument* open_file_triplex (const QString &triplex);
-  void reload_recent_list (void);
+  void reload_recent_list();
 
   void save_to_session (const QString &fileName);
   void load_from_session (const QString &fileName);
   void load_palette (const QString &fileName);
 
   void close_by_idx (int i);
-  void close_current (void);
-  void apply_settings (void);
+  void close_current();
+  void apply_settings();
   void apply_settings_single (CDocument *d);
 
   void add_to_recent (CDocument *d);
@@ -268,4 +288,27 @@ class document_holder: public QObject
   void open_recent();
 };
 
+
+class LineNumberArea: public QWidget
+{
+public:
+
+    CTEAEdit *codeEditor;
+
+    LineNumberArea (CTEAEdit *editor = 0) : QWidget (editor) {
+        codeEditor = editor;
+    }
+
+    QSize sizeHint() const {
+        return QSize(codeEditor->lineNumberAreaWidth(), 0);
+    }
+
+protected:
+    void paintEvent(QPaintEvent *event) {
+        codeEditor->lineNumberAreaPaintEvent(event);
+    }
+
+};
+
+
 #endif
