@@ -42,6 +42,13 @@ void CImgViewer::set_image_full (const QString &fname)
 }
 
 
+void CImgViewer::set_image_full_clipboard()
+{
+  window_full.show_image_from_clipboard();
+}
+
+
+
 QString CImgViewer::get_the_thumb_name (const QString &img_fname)
 {
  
@@ -80,6 +87,8 @@ CViewerWindow::CViewerWindow (QWidget *parent): QWidget (parent)
   current_index = 0; 
   angle = 0.0;
   scale = 100;
+  
+  //rubber_band = new  QRubberBand (QRubberBand::Rectangle, this);
   img_full = new QLabel (tr ("preview"));
   img_full->setAlignment (Qt::AlignCenter);
   QVBoxLayout *lt = new QVBoxLayout;
@@ -93,6 +102,9 @@ void CViewerWindow::show_image (const QString &fname)
   if (fname.isEmpty())
      return;
   
+  if (! file_exists (fname))
+      return; 
+  
   QPixmap pm (fname);
   if (scale != 100)
      pm = pm.scaledToWidth (get_value (pm.width(), scale));
@@ -131,7 +143,7 @@ void CViewerWindow::show_image (const QString &fname)
           };
   
   QString s_wnd_title (QFileInfo (fname).fileName());
-  s_wnd_title.append (QString (" %1x%2").arg (pm.width()).arg(pm.height()));
+  s_wnd_title.append (QString (" - %1x%2").arg (pm.width()).arg(pm.height()));
   setWindowTitle (s_wnd_title);
 }
 
@@ -145,6 +157,11 @@ void CViewerWindow::show_again()
   if (scale != 100)
      pm = pm.scaledToWidth (get_value (pm.width(), scale));
 
+  //int rb_w = get_value (rubber_band->width(), scale);
+  //int rb_h = get_value (rubber_band->height(), scale);
+    
+  //rubber_band->resize (rb_w, rb_h);
+                           
   QTransform transform;
   transform.rotate (angle);
     
@@ -154,7 +171,7 @@ void CViewerWindow::show_again()
   img_full->setPixmap (pixmap);
   
   QString s_wnd_title (QFileInfo (file_name).fileName());
-  s_wnd_title.append (QString (" %1x%2").arg (pm.width()).arg(pm.height()));
+  s_wnd_title.append (QString (" - %1x%2").arg (pm.width()).arg(pm.height()));
   setWindowTitle (s_wnd_title);
 }
 
@@ -166,7 +183,7 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
       event->accept();
       close();
      }
-     
+
   if ((event->key() == Qt::Key_Space) ||
       event->key() == Qt::Key_PageDown)
      {
@@ -176,7 +193,7 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
       event->accept();
       return;
      }
-  
+
   if (event->key() == Qt::Key_PageUp)
      {
       if (current_index != 0)
@@ -201,7 +218,7 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
       event->accept();
       return;
      }
-  
+
   if (event->key() == Qt::Key_BracketRight)
      {
       angle += 90.0;
@@ -233,7 +250,7 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
       return;
      }
 
-   if (event->key() == Qt::Key_Minus)
+  if (event->key() == Qt::Key_Minus)
      {
       if (scale > 10)
          scale -= 10;
@@ -245,3 +262,51 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
   
   QWidget::keyPressEvent (event);
 }
+
+
+void CViewerWindow::show_image_from_clipboard()
+{
+  
+  QClipboard *clipboard = QApplication::clipboard();
+  const QMimeData *mimeData = clipboard->mimeData();
+
+  if (! mimeData->hasImage()) 
+     return;
+          
+  QPixmap pm (qvariant_cast<QPixmap>(mimeData->imageData()));
+  if (scale != 100)
+     pm = pm.scaledToWidth (get_value (pm.width(), scale));
+  
+  resize (pm.width() + 5, pm.height() + 5);
+  img_full->setPixmap (pm);
+  
+  file_name = "";
+  
+  QString s_wnd_title (tr ("Clipboard"));
+  s_wnd_title.append (QString (" - %1x%2").arg (pm.width()).arg(pm.height()));
+  setWindowTitle (s_wnd_title);
+}
+
+/*
+
+void CViewerWindow::mousePressEvent(QMouseEvent *event)
+ {
+  orgn = event->pos();
+     //if (!rubberBand)
+       //  rubberBand = new QRubberBand(QRubberBand::Rectangle, this);
+     rubber_band->setGeometry(QRect(orgn, QSize()));
+     rubber_band->show();
+ }
+
+void CViewerWindow::mouseMoveEvent(QMouseEvent *event)
+ {
+     rubber_band->setGeometry(QRect(orgn, event->pos()).normalized());
+ }
+
+ void CViewerWindow::mouseReleaseEvent(QMouseEvent *event)
+ {
+     //rubber_band->hide();
+     // determine selection, for example using QRect::intersects()
+     // and QRect::contains().
+ }
+*/
