@@ -17,14 +17,22 @@ public:
    int current_index;
    
    QLabel *img_full;
+
+   //QPoint orgn;
+   //QRubberBand *rubber_band;
    
    CViewerWindow (QWidget *parent = 0);
    void show_image (const QString &fname);
+   void show_image_from_clipboard();
+
    void show_again();
    
 protected:
 
   void keyPressEvent (QKeyEvent *event);    
+ // void mousePressEvent(QMouseEvent *event);
+ // void mouseMoveEvent(QMouseEvent *event);
+ // void mouseReleaseEvent(QMouseEvent *event);
 };
 
 
@@ -42,6 +50,7 @@ public:
   CImgViewer (QObject *parent = 0);
   void set_image_mini (const QString &fname);
   void set_image_full (const QString &fname);
+  void set_image_full_clipboard();
 
   QString get_the_thumb_name (const QString &img_fname);
 };
