@@ -1,5 +1,5 @@
  /**************************************************************************
- *   Copyright (C) 2007-2009 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2010 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,7 +41,6 @@
 
 
 
-
 class CMarkupPair: public QObject
 {
   Q_OBJECT
@@ -50,7 +49,6 @@ public:
 
   QHash <QString, QString> tags_a;
   QHash <QString, QString> tags_b;
-
 };
 
 
@@ -88,7 +86,7 @@ public slots:
 };
 
 
-class CReloadWindow: public QWidget
+class CTextListWindow: public QWidget
 {
   Q_OBJECT
 
@@ -96,7 +94,7 @@ public:
 
   QListWidget *list;
   
-  CReloadWindow (const QStringList &all, const QStringList &used);
+  CTextListWindow (const QString &title, const QString &label_text);
 
 protected:
 
@@ -104,6 +102,9 @@ protected:
 };
 
 
+class CScriptedApp;
+
+
 class rvln: public QMainWindow
 {
   Q_OBJECT
@@ -114,15 +115,21 @@ public:
   ~rvln();
 
   int fm_entry_mode; 
-    
+
+  QDate date1;
+  QDate date2;
+
+
+  //QxtWindowSystem window_system;
+
+  CScriptedApp *scripted_app;
   CLogMemo *log;
+  
   CShortcuts *shortcuts;
   CFMan *fman;
   CImgViewer *img_viewer;
-
   document_holder *documents;
 
-
 #ifdef SPELLCHECK_ENABLE
 
   ASpellchecker *spellchecker;
@@ -131,20 +138,21 @@ public:
 
 #endif
   
-
   
   bool b_preview;
-  
+  bool capture_desktop;
+
+  int idx_tab_calendar;
   int idx_tab_edit;
   int idx_tab_tune;
   int idx_tab_fman;
   int idx_tab_learn;
+  
   int idx_prev;
   
   int fman_find_idx;
-  QList<QStandardItem *> l_fman_find;
+  QList <QStandardItem *> l_fman_find;
   
-  int pbar_step;
   bool ui_update;
 
   QScriptEngine script_engine;
@@ -152,12 +160,12 @@ public:
 
   QToolBar *tb_fman_dir;
   QLabel *l_fman_preview;
-  QTimer timer;
-
+ 
   QStringList sl_places_bmx;
   QStringList sl_urls;
   QStringList sl_charsets;
   QStringList sl_last_used_charsets;
+  QStringList sl_fif_history;
 
   QHash <QString, QString> programs;
   QHash <QString, QString> places_bookmarks;
@@ -167,10 +175,9 @@ public:
 
   QDir dir_lv;
 
-  QCompleter *cmpl_fif;
-  QStandardItemModel *cmpl_fif_model;
+  QComboBox *cmb_fif;
+  
 
-  QLineEdit *ed_man_search;
   QString man_search_value;
 
   QString markup_mode;
@@ -182,7 +189,7 @@ public:
   QString fman_fname_to_find;
 
   QString dir_user_dict;
-  
+  QString dir_profiles;  
   QString dir_last;
   QString dir_config;
   QString dir_templates;
@@ -193,6 +200,7 @@ public:
   QString dir_scripts;
   QString dir_palettes;
   QString dir_tables;
+  QString dir_days;
   
   QString fname_def_palette;
   QString fname_hls_cache;
@@ -212,11 +220,17 @@ public:
   QProgressBar *pb_status;
   QLineEdit *ed_spellcheck_path;
 
+  QCheckBox *cb_wordwrap;
+  QCheckBox *cb_show_linenums;
+  QCheckBox *cb_hl_current_line;
+  QCheckBox *cb_show_margin;
+
 protected:
 
   void closeEvent (QCloseEvent *event);
   bool fman_tv_eventFilter (QObject *obj, QEvent *event);
 
+
 private slots:
 
 /*************************
@@ -243,12 +257,14 @@ main window callbacks
   void fman_open();
   void fman_home();
   void fman_places_itemActivated (QListWidgetItem *item);
+  void fman_select_by_regexp();
+  void fman_deselect_by_regexp();
+  void fman_count_lines_in_selected_files();
 
   void cb_button_saves_as();
 
   void pageChanged (int index);
 
-  void iterate_pbar();
   void file_print();
 
   void newFile();
@@ -277,6 +293,14 @@ main window callbacks
   void file_save_bak();
   void test();
 
+  void view_use_profile();
+
+  void cal_set_date_a();
+  void cal_set_date_b();
+
+  void cal_remove();
+
+
   bool save();
   bool saveAs();
 
@@ -295,6 +319,9 @@ main window callbacks
 
   void ed_indent();
   void ed_unindent();
+ 
+  void ed_comment();
+
   
   void upCase();
   void dnCase();
@@ -327,6 +354,10 @@ main window callbacks
   void fn_filter_rm_greater_than();
   void fn_filter_rm_duplicates();
   void fn_filter_rm_empty();
+
+  void fn_filter_delete_before_sep();
+  void fn_filter_delete_after_sep();
+
   void fn_rm_formatting();
   void fn_convert_quotes();
   void fn_get_words_count();
@@ -366,6 +397,16 @@ main window callbacks
 
 #endif
 
+  void search_in_files_results_dclicked (QListWidgetItem *item);
+  void search_in_files();
+
+
+  void calendar_clicked (const QDate &date);
+  void calendar_activated (const QDate &date);
+
+  void cb_start_week_on_sunday_changed (int state);
+
+
   void mrkup_bold();
   void mrkup_italic();
   void mrkup_underline();
@@ -415,18 +456,24 @@ main window callbacks
 
   void fn_use_table();
 
+
+   void calendar_currentPageChanged ( int year, int month);
+
 /*************************
 prefs window callbacks
 *************************/
 
+
   void man_find_find();
   void man_find_next();
   void man_find_prev();
 
   void cmb_output_image_fmt_currentIndexChanged (const QString &text);
 
+  
+
   void cb_locale_override (int state);
-  void ed_locale_override_editingFinished ();
+  void ed_locale_override_editingFinished();
   void cb_session_restore (int state);
   void cb_wordwrap_changed (int state);
   void cb_hl_brackets_changed (int state);
@@ -434,6 +481,17 @@ prefs window callbacks
   void cb_spaces_instead_of_tabs_changed (int state);
   void slot_tab_sp_width_changed (int i); 
 
+  void fman_mk_gallery();
+
+  void indent_by_first_line();
+
+  void profile_save_as();
+
+
+  void ed_side_size_editingFinished();
+  void ed_link_options_editingFinished();
+  void ed_cols_per_row_editingFinished();
+
   void cb_auto_img_preview_changed (int state);
 
   void pb_assign_hotkey_clicked();
@@ -457,14 +515,14 @@ prefs window callbacks
   void cb_img_post_proc (int state);
   void slot_img_quality_changed (int i);
 
+  void cb_show_linenums_changed (int state);
+
   void cb_show_margin_changed (int state);
   void margin_pos_changed (int i);
   void cb_cursor_center_on_scroll (int state);
 
-  
-////////////////////////////  
-  
-  
+  void process_readyReadStandardOutput();
+
   
   
   void fman_naventry_confirm();
@@ -475,6 +533,30 @@ prefs window callbacks
   void fman_save_zip();
   void fman_preview_image();
 
+  void set_eol_unix();
+  void set_eol_win();
+  void set_eol_mac();
+
+  void guess_enc();
+
+#ifndef Q_OS_OS2
+  
+  void fn_show_image_from_clipboard();
+  void fn_capture_screen();
+  void capt_active_wnd_image();
+  void capt_desktop_image();
+  void image_save_from_clipboard();
+
+#endif
+
+  void screenshot_delay_changed (int i);
+
+
+  void cal_add_days();
+  void cal_add_months();
+  void cal_add_years();
+  
+
 private:
 
 /*************************
@@ -494,6 +576,12 @@ main window widgets
 
   QMenu *fileMenu;
   QMenu *editMenu;
+  QMenu *menu_cal;
+
+  QMenu *menu_cal_add;
+  QMenu *menu_cal_sub;
+  QMenu *menu_cal_diff;
+
 
   QMenu *menu_file_edit_bookmarks;
 
@@ -507,11 +595,14 @@ main window widgets
   QMenu *menu_fn_tables;
   QMenu *menu_view_palettes;
   QMenu *menu_view_hl;
+  QMenu *menu_view_profiles;
+
   QMenu *menu_fn_sessions;
   QMenu *menu_fn_scripts;
   QMenu *menu_markup;
   QMenu *menu_functions;
   QMenu *menu_functions_case;
+
   QMenu *menu_file_recent;
   QMenu *menu_search;
   QMenu *menu_nav;
@@ -550,6 +641,9 @@ main window widgets
   QComboBox *cb_fman_codecs;
   QComboBox *cb_fman_drives;
 
+
+  QCalendarWidget *calendar;
+
 /*************************
 prefs window widgets
 *************************/
@@ -558,6 +652,14 @@ prefs window widgets
 
   QLineEdit *ed_date_format;
   QLineEdit *ed_time_format;
+
+  QLineEdit *ed_side_size;
+  QLineEdit *ed_link_options;
+  QLineEdit *ed_cols_per_row;
+
+  //QSpinBox *spb_screenshot_delay;
+
+
   QLineEdit *ed_locale_override;
 
   CShortcutEntry *ent_shtcut;
@@ -586,6 +688,8 @@ prefs window widgets
   void update_dyn_menus();
   void create_paths();
   
+  void calendar_update();
+
 
 #ifdef SPELLCHECK_ENABLE
 
@@ -601,6 +705,8 @@ prefs window widgets
   void createActions();
   void createMenus();
   void createOptions();
+  void createCalendar();
+
   void createManual();
   void updateFonts();
   void update_bookmarks();
@@ -619,13 +725,14 @@ prefs window widgets
   void update_logmemo_palette();
 
   void update_charsets();
+  void update_profiles();
+
+
   void createToolBars();
   void createStatusBar();
   void readSettings();
   void writeSettings();
 
-  void completer_init();
-
   void read_search_options();
   void write_search_options();
 
@@ -637,31 +744,52 @@ prefs window widgets
   void create_markup_hash();
 
   void count_substring (bool use_regexp);
-  void fn_filter_less_greater (bool less);
 
   void run_unitaz (int mode);
   void run_js_script (const QString &fname);
-
-  void cmpl_fif_model_add (const QString &value);
-
-  void fif_model_read();
-  void fif_model_write();
-
+ 
   QTextDocument::FindFlags get_search_options();
-  void fman_convert_images (bool by_side, int value);
 
+  void fman_convert_images (bool by_side, int value);
+ 
   QString fif_get_text();
+  void fn_filter_delete_by_sep (bool mode);
+
+  void fman_items_select_by_regexp (bool mode);
 
   void fman_find();
   void fman_find_next();
   void fman_find_prev();
-
-  
+ 
   void opt_update_keyb();
   
   void opt_shortcuts_find();
   void opt_shortcuts_find_next();
   void opt_shortcuts_find_prev();
+
+
+  void idx_tab_edit_activate();
+  void idx_tab_calendar_activate();
+  void idx_tab_tune_activate();
+  void idx_tab_fman_activate();
+  void idx_tab_learn_activate();
+
+  
+};
+
+
+class CScriptedApp: public QObject
+{
+  Q_OBJECT
+
+public:
+
+  rvln *app; 
+
+public slots:
+
+  QString version();
+  void call_menuitem (const QString &value);
 };
 
 
