@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2009 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2010 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -68,7 +68,7 @@ CSpellchecker::~CSpellchecker()
   if (spell_config)
      delete_aspell_config (spell_config);
 
-  qDebug() << "~CSpellchecker()";
+  //qDebug() << "~CSpellchecker()";
 }
 
 
@@ -195,8 +195,6 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
       user_words = qstring_load (fname_userdict, encoding).split ("\n");  
       user_words.removeFirst();
      } 
-
-  qDebug() << "starting hunspell with " << fname_aff << " " << fname_dict;
 }
 
 
@@ -208,7 +206,6 @@ CHunspellChecker::~CHunspellChecker()
   qstring_save (filename, user_words.join ("\n"), encoding);
 
   delete speller;
-  qDebug() << "~CHunspellChecker()"; 
 }
 
 
@@ -295,7 +292,7 @@ QStringList CHunspellChecker::get_suggestions_list (const QString &word)
 
   char **slst;
     
-  int size = speller-> suggest(&slst, es.data());
+  int size = speller->suggest(&slst, es.data());
   
   for (int i = 0; i < size; i++)
       sl.append (codec->toUnicode (slst[i]));
