@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2009 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2010 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -40,13 +40,37 @@ typedef struct {
                } t_wav_chunk_fmt;
 
 
+
+class CFilesList: public QObject
+{
+public:
+
+  QStringList list;
+
+  void get (const QString &path);
+  void iterate (QFileInfo &fi);
+};
+
+
+class CFTypeChecker: public QObject
+{
+public:
+
+  QStringList lexts;
+  QStringList lnames;
+
+  CFTypeChecker (const QString &fnames, const QString &exts);
+  bool check (const QString &fname);
+};
+
+
 class CWavReader: public QObject
 {
 public:
 
-   t_wav_chunk_fmt wav_chunk_fmt;
-   double rms;
-   bool get_info (const QString fname);
+  t_wav_chunk_fmt wav_chunk_fmt;
+  double rms;
+  bool get_info (const QString fname);
 };
 
 QString hash_keyval_to_string (const QHash<QString, QString> &h);
@@ -94,11 +118,12 @@ QPixmap pixmap_scale_by (const QPixmap &source,
                          Qt::TransformationMode mode);
 
 QString change_file_ext (const QString &s, const QString &ext);
-QStringList bytearray_to_stringlist (QList<QByteArray> a);
+QStringList bytearray_to_stringlist (QList <QByteArray> a);
 QString qstring_get_last_after (const QString &s, const QString &sep);
 QString int_to_binary (int n);
 QString string_reverse (const QString &s);
 unsigned int bin_to_decimal (const QString &s);
+QString get_insert_image (const QString &file_name, const QString &full_path, const QString &markup_mode);
 
 
 inline int get_value (int total, int perc)
